#' Precooked results for demonstrating plotting
#' @description
#'   These are all pre-cooked results objects, saved here to save time in
#'   testing and demonstrating how autograph plots look.
#' @docType data
#' @keywords datasets
#' @name made_earlier
#' @usage data(res_migraph_reg)
"res_migraph_reg"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(res_migraph_test)
"res_migraph_test"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(res_migraph_diff)
"res_migraph_diff"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(res_manynet_diff)
"res_manynet_diff"

# RSiena objects ####

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(siena_gof)
"siena_gof"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(siena_influence)
"siena_influence"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(siena_selection)
"siena_selection"

# MoNAn objects ####

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(monan_conv)
"monan_conv"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(monan_gof)
"monan_gof"

# ERGM objects ####

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(ergm_res)
"ergm_res"

#' @docType data
#' @keywords datasets
#' @rdname made_earlier
#' @usage data(ergm_gof)
"ergm_gof"
